g.binread:
function to read binary files as produced by the accelerometer named 'Genea',
not to be confused with the 'GENEActiv' (see package GENEAread for this)
Description
For reading the binary data as collected with a Genea accelerometer
(Unilever Discover, UK). For reading GENEActive binary data, see package GENEAread.
Usage
g.binread(binfile, start = 0, end = 0)
Arguments
binfile
filename (required)
start
start point for reading data, this can either be a timestamp
"year-month-day hr:min:sec" or a page number (optional)
end
end point for reading data, this can either be a timestamp
"year-month-day hr:min:sec" or a page number (optional)
Value
Details
If only start is defined then g.binread will read all data beyond
start until the end of the file is reached