Learn R Programming

GGIR (version 1.4)

g.plot: function to generate a plot for quality check purposes

Description

Function takes meta-data as generated by g.getmeta and g.impute to create a visual representation of imputed time periods

Usage

g.plot(IMP, M, I, durplot)

Arguments

IMP
output from g.impute
M
output from g.getmeta
I
output from g.inspectfile
durplot
number of days to plot

Value

function only produces a plot, no values

Examples

Run this code
## Not run: 
#   #inspect file:
#   I = g.inspectfile(datafile)
#   
#   #autocalibration:
#   C = g.calibrate(datafile) 
#   
#   #get meta-data:
#   M = g.getmeta(datafile)
# ## End(Not run)
data(data.getmeta)
data(data.inspectfile)

#impute meta-data:
IMP = g.impute(M = data.getmeta, I = data.inspectfile, strategy = 1,
hrs.del.start = 0, hrs.del.end = 0, maxdur = 0)

#plot data
g.plot(IMP, M = data.getmeta, I = data.inspectfile, durplot=4)

Run the code above in your browser using DataLab