Creates report from milestone data produced by g.part2. Not intended for direct use by package user
g.report.part2(metadatadir=c(), f0=c(), f1=c(), maxdur = 0,
selectdaysfile=c(), store.long=FALSE, do.part2.pdf = TRUE)File index to start with (default = 1). Index refers to the filenames sorted in alphabetical order
File index to finish with (defaults to number of files available, i.e., f1 = 0)
see g.part2
see g.part2
Booelean to indicate whether output should stored in long format in addition to default wide format. Automatically turned to TRUE if using day segmentation with qwindow.
Boolean, see g.part2
Function does not produce data, but only writes reports in csv format and visual reports in pdf format