For reading the wav accelerometer data as collected with an Axivity accelerometer
g.wavread(wavfile, start = 1, end = 100,units="minutes")filename (required)
start point for reading data, see also units
end point for reading data, see also units
units used for defining start and end
rawxyzmatrix with raw x, y, and, z acceleration values
headerfile header
timestampslocal timestamps for rawxyz
If only start is defined then g.binread will read all data beyond
start until the end of the file is reached