# Estimate self-similarity of a very known time series available on R base: the sunspot.year.
# Then the spend time with each method is compared.
if (FALSE) {
ssp_results = SSP(sunspot.year)
ssp_results$alpha_overall
ssp_results$alpha_1
ssp_results$alpha_2
}
Run the code above in your browser using DataLab