Usage
g.calibrate(datafile, use.temp = TRUE, spherecrit = 0.3, minloadcrit = 72,
printsummary = TRUE,chunksize=c(),windowsizes=c(5,900,3600),selectdaysfile=c(),
dayborder=0)
Arguments
datafile
name of accelerometer file
use.temp
use temperature sensor data if available (Geneactive only)
spherecrit
the minimum required acceleration value (in g) on both sides of 0 g
for each axis. Used to judge whether the sphere is sufficiently populated
minloadcrit
the minimum number of hours the code needs to read for the
autocalibration procedure to be effective (only sensitive to multitudes of 12 hrs,
other values will be ceiled). After loading these hours only extra data is loaded
if calibration error has not been reduced to under 0.01 g.
printsummary
if TRUE will print a summary when done
chunksize
number between 0.2 and 1 to specificy the size of chunks to be
loaded as a fraction of a 12 hour period, e.g. 0.5 equals 6 hour chunks.
The default is 1 (12 hrs). For machines with less than 4Gb of RAM memory a value
below 1 is recommended.