Usage
g.part2(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy = 1, hrs.del.start = 0.5,
hrs.del.end = 0.5, maxdur = 7, includedaycrit = 16,
L5M5window = c(0,24), M5L5res = 10, winhr = 5, qwindow=c(0,24), qlevels = c(0.1),
ilevels = c(0,10), mvpathreshold = c(100),boutcriter = 0.8,ndayswindow=7,idloc=1,
do.imp=TRUE,storefolderstructure=FALSE,overwrite=FALSE,epochvalues2csv=FALSE,
mvpadur=c(1,5,10),selectdaysfile=c(),window.summary.size=10,dayborder=0,
bout.metric=2,closedbout=FALSE,desiredtz="Europe/London")
Arguments
datadir
Directory where the accelerometer files are stored or list, e.g. "C:/mydata"
of accelerometer filenames and directories,
e.g. c("C:/mydata/myfile1.bin","C:/mydata/myfile2.bin").
metadatadir
Directory where the output from g.part1 was stored
f0
File index to start with (default = 1). Index refers to the filenames sorted
in increasing order
f1
File index to finish with (defaults to number of files available)
strategy
how to deal with knowledge about study protocol. value = 1 to select data
based on hrs.del.start, hrs.del.end, and maxdur.
Value = 2 to only use the data between the first midnight and the last
midnight, value = 3 only selects the most active X days
in the files. X is specified by argument ndayswindow
See also g.impute
hrs.del.start
how many HOURS after start of experiment did wearing of monitor start?,
see g.impute
hrs.del.end
how many HOURS before the end of the experiment did wearing of monitor
definitely end?, see g.impute
maxdur
how many DAYS after start of experiment did experiment
definitely stop? (set to zero if unknown = default), see g.impute
includedaycrit
minimum required number of valid hours in day specific analysis
(NOTE: there is no minimum required number of hours per day in the summary
of an entire measurement, every available hour is used to make the best possible
inference on average metric value per week)
L5M5window
start and end time, in 24 hour clock hours, over which L5M5 needs to be
calculated. The calculation is done based on the average day
M5L5res
resoltion of L5 and M5 analysis in minutes (default: 10 minutes)
winhr
window size in hours of L5 and M5 analysis (dedault = 5 hours)
qwindow
start and end time, in 24 hour clock hours, over which distribution in metric
values need to be extracted. Value = c(0,24) will consider all 24 hours.
qlevels
array of percentiles for which value needs to be extracted. These need to
be expressed as a fraction of 1, e.g. c(0.1, 0.5, 0.75). There is no limit
to the number of percentiles. If left empty then percentiles will not be
extracted. Distribution will be derived from short epoch metric data, see
g.getmeta.
ilevels
Levels for acceleration value frequency distribution in mg, e.g. c(0,100,200)
There is no constriction to the number of levels.
mvpathreshold
Threshold for MVPA estimation. Threshold needs to be based on metric ENMO.
This can be a single number or an array of numbers, e.g. c(100,120). In the
later case the code will estimate MVPA seperately for each threshold. If
this variable is left blank c() then MVPA is not estimated
boutcriter
The variable boutcriter is a number between 0 and 1 and defines what fraction
of a bout needs to be above the mvpathreshold
ndayswindow
If strategy is set to 3 then this is the size of the window as a number
of days
idloc
If value = 1 (default) the code assumes that ID number is stored in the
obvious header field. If value = 2 the code uses the character string preceding
the character '_' in the filename as the ID number
do.imp
Whether to impute missing values (e.g. suspected of monitor non-wear) or not
by g.impute. Default and recommended setting is TRUE
storefolderstructure
Store folder structure of the accelerometer data
overwrite
Overwrite previously generated milestone data by this function for this
particular dataset. If FALSE then it will skip the previously processed files
(default = FALSE).
epochvalues2csv
If TRUE then epoch values are exported to a CSV spreadsheet. Here, non-wear time
is imputed where possible (default = FALSE).
mvpadur
default = c(1,5,10). Three bout duration for which MVPA will be calculated
selectdaysfile
Functionality designed for the London Centre of Longidutinal studies.
Csv file holding the relation between device serial numbers and measurement days of interest.
dayborder
Hour at which days start and end (default = 0), value = 4 would mean 4am
window.summary.size
Functionality designed for the London Centre of Longidutinal studies.
Size in minutes of the summary window
bout.metric
This argument used to be called mvpa.2014 and had TRUE or FALSE as its value.
However, it has now become clear that this aspect of the analyses is still very
much open for debate. Therefore, I have changed it into an argument where you
can specify a metric for bout detection based on a number. A description of these
bout metrics can be found in the new function g.getbout