Learn R Programming

GGIR (version 1.4)

g.wavread: function to read .wav files as produced by the accelerometer named 'Axivity'

Description

For reading the wav accelerometer data as collected with an Axivity accelerometer

Usage

g.wavread(wavfile, start = 1, end = 100,units="minutes")

Arguments

wavfile
filename (required)
start
start point for reading data, see also units
end
end point for reading data, see also units
units
units used for defining start and end

Value

Details

If only start is defined then g.binread will read all data beyond start until the end of the file is reached